# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/home/w0rm/projects/python/pyqtrailer/pyqtrailer/qtcustom/settings.ui'
#
# Created: Fri Oct 22 17:48:37 2010
#      by: PyQt4 UI code generator 4.7.7
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_SettingsDialog(object):
    def setupUi(self, SettingsDialog):
        SettingsDialog.setObjectName(_fromUtf8("SettingsDialog"))
        SettingsDialog.resize(467, 404)
        self.gridLayout = QtGui.QGridLayout(SettingsDialog)
        self.gridLayout.setObjectName(_fromUtf8("gridLayout"))
        self.groupBox_2 = QtGui.QGroupBox(SettingsDialog)
        self.groupBox_2.setObjectName(_fromUtf8("groupBox_2"))
        self.horizontalLayout = QtGui.QHBoxLayout(self.groupBox_2)
        self.horizontalLayout.setObjectName(_fromUtf8("horizontalLayout"))
        self.downloadPath = QtGui.QLineEdit(self.groupBox_2)
        self.downloadPath.setText(_fromUtf8(""))
        self.downloadPath.setObjectName(_fromUtf8("downloadPath"))
        self.horizontalLayout.addWidget(self.downloadPath)
        self.browseButton = QtGui.QPushButton(self.groupBox_2)
        self.browseButton.setObjectName(_fromUtf8("browseButton"))
        self.horizontalLayout.addWidget(self.browseButton)
        self.gridLayout.addWidget(self.groupBox_2, 0, 0, 1, 2)
        self.groupBox = QtGui.QGroupBox(SettingsDialog)
        self.groupBox.setMaximumSize(QtCore.QSize(16777215, 150))
        self.groupBox.setObjectName(_fromUtf8("groupBox"))
        self.gridLayout_2 = QtGui.QGridLayout(self.groupBox)
        self.gridLayout_2.setObjectName(_fromUtf8("gridLayout_2"))
        self.filterList = QtGui.QListWidget(self.groupBox)
        sizePolicy = QtGui.QSizePolicy(QtGui.QSizePolicy.Preferred, QtGui.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.filterList.sizePolicy().hasHeightForWidth())
        self.filterList.setSizePolicy(sizePolicy)
        self.filterList.setMinimumSize(QtCore.QSize(80, 110))
        self.filterList.setMaximumSize(QtCore.QSize(80, 110))
        self.filterList.setObjectName(_fromUtf8("filterList"))
        QtGui.QListWidgetItem(self.filterList)
        QtGui.QListWidgetItem(self.filterList)
        QtGui.QListWidgetItem(self.filterList)
        QtGui.QListWidgetItem(self.filterList)
        QtGui.QListWidgetItem(self.filterList)
        QtGui.QListWidgetItem(self.filterList)
        self.gridLayout_2.addWidget(self.filterList, 0, 0, 3, 1)
        self.qualityUp = QtGui.QToolButton(self.groupBox)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(_fromUtf8("../../../../../../../usr/share/icons/oxygen/32x32/actions/go-up.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.qualityUp.setIcon(icon)
        self.qualityUp.setObjectName(_fromUtf8("qualityUp"))
        self.gridLayout_2.addWidget(self.qualityUp, 0, 1, 1, 1)
        self.qualityDown = QtGui.QToolButton(self.groupBox)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(_fromUtf8("../../../../../../../usr/share/icons/oxygen/32x32/actions/go-down.png")), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.qualityDown.setIcon(icon1)
        self.qualityDown.setObjectName(_fromUtf8("qualityDown"))
        self.gridLayout_2.addWidget(self.qualityDown, 1, 1, 1, 1)
        spacerItem = QtGui.QSpacerItem(20, 45, QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Expanding)
        self.gridLayout_2.addItem(spacerItem, 2, 1, 1, 1)
        self.gridLayout.addWidget(self.groupBox, 1, 0, 1, 1)
        self.groupBox_3 = QtGui.QGroupBox(SettingsDialog)
        self.groupBox_3.setMaximumSize(QtCore.QSize(16777215, 150))
        self.groupBox_3.setObjectName(_fromUtf8("groupBox_3"))
        self.verticalLayout = QtGui.QVBoxLayout(self.groupBox_3)
        self.verticalLayout.setObjectName(_fromUtf8("verticalLayout"))
        self.horizontalLayout_3 = QtGui.QHBoxLayout()
        self.horizontalLayout_3.setObjectName(_fromUtf8("horizontalLayout_3"))
        self.label = QtGui.QLabel(self.groupBox_3)
        self.label.setObjectName(_fromUtf8("label"))
        self.horizontalLayout_3.addWidget(self.label)
        spacerItem1 = QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.horizontalLayout_3.addItem(spacerItem1)
        self.spinReadAhead = QtGui.QSpinBox(self.groupBox_3)
        self.spinReadAhead.setMaximumSize(QtCore.QSize(16777215, 30))
        self.spinReadAhead.setMinimum(1)
        self.spinReadAhead.setMaximum(10)
        self.spinReadAhead.setProperty(_fromUtf8("value"), 4)
        self.spinReadAhead.setObjectName(_fromUtf8("spinReadAhead"))
        self.horizontalLayout_3.addWidget(self.spinReadAhead)
        self.verticalLayout.addLayout(self.horizontalLayout_3)
        self.horizontalLayout_2 = QtGui.QHBoxLayout()
        self.horizontalLayout_2.setObjectName(_fromUtf8("horizontalLayout_2"))
        self.label_2 = QtGui.QLabel(self.groupBox_3)
        self.label_2.setObjectName(_fromUtf8("label_2"))
        self.horizontalLayout_2.addWidget(self.label_2)
        spacerItem2 = QtGui.QSpacerItem(40, 20, QtGui.QSizePolicy.Expanding, QtGui.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem2)
        self.spinParallelDownload = QtGui.QSpinBox(self.groupBox_3)
        self.spinParallelDownload.setMaximumSize(QtCore.QSize(16777215, 30))
        self.spinParallelDownload.setMinimum(1)
        self.spinParallelDownload.setMaximum(5)
        self.spinParallelDownload.setProperty(_fromUtf8("value"), 2)
        self.spinParallelDownload.setObjectName(_fromUtf8("spinParallelDownload"))
        self.horizontalLayout_2.addWidget(self.spinParallelDownload)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.gridLayout.addWidget(self.groupBox_3, 1, 1, 1, 1)
        self.groupBox_4 = QtGui.QGroupBox(SettingsDialog)
        self.groupBox_4.setObjectName(_fromUtf8("groupBox_4"))
        self.verticalLayout_2 = QtGui.QVBoxLayout(self.groupBox_4)
        self.verticalLayout_2.setObjectName(_fromUtf8("verticalLayout_2"))
        self.horizontalLayout_4 = QtGui.QHBoxLayout()
        self.horizontalLayout_4.setObjectName(_fromUtf8("horizontalLayout_4"))
        self.label_3 = QtGui.QLabel(self.groupBox_4)
        self.label_3.setObjectName(_fromUtf8("label_3"))
        self.horizontalLayout_4.addWidget(self.label_3)
        self.playerCommand = QtGui.QLineEdit(self.groupBox_4)
        self.playerCommand.setObjectName(_fromUtf8("playerCommand"))
        self.horizontalLayout_4.addWidget(self.playerCommand)
        self.verticalLayout_2.addLayout(self.horizontalLayout_4)
        self.label_4 = QtGui.QLabel(self.groupBox_4)
        self.label_4.setObjectName(_fromUtf8("label_4"))
        self.verticalLayout_2.addWidget(self.label_4)
        self.label_5 = QtGui.QLabel(self.groupBox_4)
        self.label_5.setObjectName(_fromUtf8("label_5"))
        self.verticalLayout_2.addWidget(self.label_5)
        self.gridLayout.addWidget(self.groupBox_4, 2, 0, 1, 2)
        self.buttonBox = QtGui.QDialogButtonBox(SettingsDialog)
        self.buttonBox.setOrientation(QtCore.Qt.Horizontal)
        self.buttonBox.setStandardButtons(QtGui.QDialogButtonBox.Cancel|QtGui.QDialogButtonBox.Ok)
        self.buttonBox.setObjectName(_fromUtf8("buttonBox"))
        self.gridLayout.addWidget(self.buttonBox, 3, 1, 1, 1)

        self.retranslateUi(SettingsDialog)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("accepted()")), SettingsDialog.accept)
        QtCore.QObject.connect(self.buttonBox, QtCore.SIGNAL(_fromUtf8("rejected()")), SettingsDialog.reject)
        QtCore.QMetaObject.connectSlotsByName(SettingsDialog)

    def retranslateUi(self, SettingsDialog):
        SettingsDialog.setWindowTitle(QtGui.QApplication.translate("SettingsDialog", "Dialog", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox_2.setTitle(QtGui.QApplication.translate("SettingsDialog", "&Download path", None, QtGui.QApplication.UnicodeUTF8))
        self.browseButton.setText(QtGui.QApplication.translate("SettingsDialog", "Browse", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox.setTitle(QtGui.QApplication.translate("SettingsDialog", "&Quality priority", None, QtGui.QApplication.UnicodeUTF8))
        __sortingEnabled = self.filterList.isSortingEnabled()
        self.filterList.setSortingEnabled(False)
        self.filterList.item(0).setText(QtGui.QApplication.translate("SettingsDialog", "480p", None, QtGui.QApplication.UnicodeUTF8))
        self.filterList.item(1).setText(QtGui.QApplication.translate("SettingsDialog", "720p", None, QtGui.QApplication.UnicodeUTF8))
        self.filterList.item(2).setText(QtGui.QApplication.translate("SettingsDialog", "1080p", None, QtGui.QApplication.UnicodeUTF8))
        self.filterList.item(3).setText(QtGui.QApplication.translate("SettingsDialog", "640x360", None, QtGui.QApplication.UnicodeUTF8))
        self.filterList.item(4).setText(QtGui.QApplication.translate("SettingsDialog", "320x180", None, QtGui.QApplication.UnicodeUTF8))
        self.filterList.item(5).setText(QtGui.QApplication.translate("SettingsDialog", "480x204", None, QtGui.QApplication.UnicodeUTF8))
        self.filterList.setSortingEnabled(__sortingEnabled)
        self.qualityUp.setText(QtGui.QApplication.translate("SettingsDialog", "...", None, QtGui.QApplication.UnicodeUTF8))
        self.qualityDown.setText(QtGui.QApplication.translate("SettingsDialog", "...", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox_3.setTitle(QtGui.QApplication.translate("SettingsDialog", "&Performance", None, QtGui.QApplication.UnicodeUTF8))
        self.label.setText(QtGui.QApplication.translate("SettingsDialog", "Read ahead processes", None, QtGui.QApplication.UnicodeUTF8))
        self.label_2.setText(QtGui.QApplication.translate("SettingsDialog", "Maxiumum parallel downloads", None, QtGui.QApplication.UnicodeUTF8))
        self.groupBox_4.setTitle(QtGui.QApplication.translate("SettingsDialog", "Viewing", None, QtGui.QApplication.UnicodeUTF8))
        self.label_3.setText(QtGui.QApplication.translate("SettingsDialog", "Command: ", None, QtGui.QApplication.UnicodeUTF8))
        self.playerCommand.setText(QtGui.QApplication.translate("SettingsDialog", "mplayer -user-agent %a %u", None, QtGui.QApplication.UnicodeUTF8))
        self.label_4.setText(QtGui.QApplication.translate("SettingsDialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Bitstream Vera Serif\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:11pt; font-weight:600;\">%u</span> will be replaced with trailer URL</p></body></html>", None, QtGui.QApplication.UnicodeUTF8))
        self.label_5.setText(QtGui.QApplication.translate("SettingsDialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:\'Bitstream Vera Serif\'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-size:11pt; font-weight:600;\">%a</span> will be replaced with user-agent string</p></body></html>", None, QtGui.QApplication.UnicodeUTF8))




import json
import locale
import re

from PyQt4.QtCore import *
from PyQt4.QtGui import *

try:
    from PyQt4.QtCore import QString
except ImportError:
    # we are using Python3 so QString is not defined
    QString = type("")

from .settings_ui import Ui_SettingsDialog
from .about_ui import Ui_AboutDialog
from .. import version
__version__ = version.__version__
import dateutil.parser as dparser

class MovieItemWidget(QFrame):
    def __init__(self, movie, trailerFilters, *args):
        QWidget.__init__(self, *args)

        self.movie = movie
        self.filters = trailerFilters

        self.titlebox = QHBoxLayout()
        releaseDate=None
        if hasattr(movie, "releasedate"):
            locale.setlocale(locale.LC_ALL, "C")
            releaseDate = dparser.parse(movie.releasedate)
            locale.resetlocale()
            releaseDate = releaseDate.strftime("%x")
        else:
            releaseDate = "Unknown release date"
        titleLabel = QLabel("<h2>%s</h2> (Release date: %s)" %
        (movie.title, releaseDate), self)
        self.setFrameStyle(QFrame.Panel | QFrame.Sunken);

        self.titlebox.addWidget(titleLabel)
        self.titlebox.addStretch(1)

        middleArea = QHBoxLayout()
        self.posterLabel = QLabel("<img src=""/>", self)
        self.posterLabel.setMinimumSize(QSize(134,193))
        self.posterLabel.setMaximumSize(QSize(134,193))

        mainArea = QVBoxLayout()
        self.mainArea = mainArea
        genre = QLabel("<b>Genre(s): </b>%s" %
                       self.__get_movie_info(movie, "genre", True))
        mainArea.addWidget(genre)

        studio = QLabel("<b>Studio: </b>%s" %
                        self.__get_movie_info(movie, "studio"))
        mainArea.addWidget(studio)

        directors = QLabel("<b>Director(s): </b>%s" %
                           self.__get_movie_info(movie, "directors"))
        mainArea.addWidget(directors)

        actors = QLabel("<b>Actors: </b>%s" %
                        self.__get_movie_info(movie, "actors", True))
        mainArea.addWidget(actors)
        actors.setWordWrap(True)
        mainArea.addStretch(1)

        middleArea.addWidget(self.posterLabel)
        middleArea.addLayout(mainArea)


        topLevelLayout = QVBoxLayout()
        topLevelLayout.addLayout(self.titlebox)
        topLevelLayout.addLayout(middleArea)
        self.setMinimumSize(400,150)
        self.setLayout(topLevelLayout)

    def __get_movie_info(self, movie, info, join=False):
        ret = "Unknown"
        if hasattr(movie, info):
            if join:
                ret = ", ".join(getattr(movie, info))
            else:
                ret = getattr(movie, info)
        return ret

    def refresh(self):

        movie = self.movie

        self.button_mapping = {}
        posterImage = QImage()
        posterImage.loadFromData(movie.poster)
        self.posterLabel.setPixmap(QPixmap.fromImage(posterImage))

        self.downloadButtons = QButtonGroup()
        self.downloadButtons.buttonClicked.connect(self.download)
        self.viewButtons = QButtonGroup()
        self.viewButtons.buttonClicked.connect(self.view)
        links = 0
        for trailerName in movie.trailerLinks:
            trailerURLS = movie.trailerLinks[trailerName]
            match = 0
            for tf in self.filters:
                cond = re.compile(tf)
                for url in trailerURLS:
                    if re.match(cond, url):
                        self._add_buttons(trailerName, url, links)
                        links = links + 1
                        match = 1
                        break
                if match == 1:
                    break


        desc = QLabel(movie.description)
        desc.setWordWrap(True)
        desc.setTextFormat(Qt.RichText)
        self.layout().addWidget(desc)

    def _add_buttons(self, trailerName, trailerLink, ids):
        trailerName = "%s (%s)" % (trailerName,
                                   PyTrailerSettings.getQualityFromURL(trailerLink))
        lab = QLabel('<a href="%s">%s</a>' % (trailerLink, trailerName), self)
        hbox= QHBoxLayout()
        button=QPushButton("Download")
        self.downloadButtons.addButton(button, ids)
        self.button_mapping[ids] = trailerLink
        hbox.addStretch(1)
        hbox.addWidget(lab)
        hbox.addWidget(button)
        button=QPushButton("View")
        self.viewButtons.addButton(button, ids)
        hbox.addWidget(button)
        self.mainArea.addLayout(hbox)

    downloadClicked = pyqtSignal((QString, ))
    viewClicked = pyqtSignal((QString, ))

    def download(self, button):
        id = self.downloadButtons.id(button)
        self.downloadClicked.emit(self.button_mapping[id])

    def view(self, button):
        id = self.viewButtons.id(button)
        self.viewClicked.emit(self.button_mapping[id])


class PyTrailerSettings(QDialog):
    filters = [('320x180',r'.*h320\.mov$'),
               ('480x204',r'.*h480\.mov$'),
               ('640x360',r'.*h640w\.mov$'),
               ('480p',r'.*480p\.mov$'),
               ('720p',r'.*720p\.mov$'),
               ('1080p',r'.*1080p\.mov$')]

    def __init__(self, config):
        QDialog.__init__(self)
        self.config = config
        self.ui = Ui_SettingsDialog()
        self.ui.setupUi(self)
        self.ui.downloadPath.setText(config.get("DEFAULT","downloadDir"))
        self.ui.spinReadAhead.setValue(int(config.get("DEFAULT","readAhead")))
        self.ui.spinParallelDownload.setValue(int(config.get("DEFAULT","parallelDownload")))

        self.ui.browseButton.clicked.connect(self.browseDir)
        self.ui.qualityUp.clicked.connect(self.filterUp)
        self.ui.qualityDown.clicked.connect(self.filterDown)

        self.ui.playerCommand.setText(config.get("DEFAULT","player"))

        activeFilters = json.loads(config.get("DEFAULT","filters"))
        self.ui.filterList.clear()
        added = []
        for filt in activeFilters:
            for fn, fregex in self.filters:
                if fregex  == filt:
                    self.ui.filterList.addItem(fn)
                    added.append(fn)

        for filt in self.filters:
            if filt[0] not in added:
                self.ui.filterList.addItem(filt[0])
                added.append(filt[0])

    def filterUp(self):
        currentRow = self.ui.filterList.currentRow()
        if currentRow == 0:
            return

        item = self.ui.filterList.takeItem(currentRow)
        self.ui.filterList.insertItem(currentRow-1, item)
        self.ui.filterList.setCurrentRow(currentRow-1)

    def filterDown(self):
        currentRow = self.ui.filterList.currentRow()
        if currentRow == self.ui.filterList.count()-1:
            return

        item = self.ui.filterList.takeItem(currentRow)
        self.ui.filterList.insertItem(currentRow+1, item)
        self.ui.filterList.setCurrentRow(currentRow+1)

    def accept(self):
        self.config.set("DEFAULT","downloadDir",
                        str(self.ui.downloadPath.text()))
        playerStr = self.ui.playerCommand.text().replace('%','%%')
        self.config.set("DEFAULT","player", playerStr)
        activeFilters = []
        for i in range(self.ui.filterList.count()):
            itemWidget = self.ui.filterList.takeItem(0)
            filterName = str(itemWidget.text())
            for fn, fregex in self.filters:
                if fn == filterName:
                    activeFilters.append(fregex)
        self.config.set("DEFAULT","filters", json.dumps(activeFilters))
        self.config.set("DEFAULT","readAhead", str(self.ui.spinReadAhead.value()))
        self.config.set("DEFAULT","parallelDownload", str(self.ui.spinParallelDownload.value()))
        QDialog.accept(self)

    def browseDir(self):
        directory = QFileDialog.getExistingDirectory(self,
                                                     QString(),
                                                     self.config.get("DEFAULT",
                                                                     "downloadDir"))
        if directory:
            self.ui.downloadPath.setText(directory)

    @staticmethod
    def getQualityFromURL(url):
        for fn, fregex in PyTrailerSettings.filters:
            if re.match(fregex, url):
                return fn
        return "Unknown quality"

class PyTrailerAbout(QDialog):
    def __init__(self, parent):
        QDialog.__init__(self)
        self.ui = Ui_AboutDialog()
        self.ui.setupUi(self)
        self._main  = parent
        self.ui.label_version.setText(__version__)
        self.connect(self.ui.buttonClose, SIGNAL("clicked(bool)"), self.close)





from multiprocessing import Process, Queue, active_children
import subprocess
import os
import signal
import locale
import errno

class ClosingException(Exception):
    pass


class DownloadStatus:
    DONE = 1
    ERROR = 2
    IN_PROGRESS = 3
    WAITING = 4

    def __init__(self, url, status, percent=0):
        self.status = status
        self.url = url
        self.percent= percent



class TrailerDownloader(object):

    def __init__(self, taskQueue, taskDict, parallelProcesses = 1):
        """taskQueue = Queue() of (url, targetDir) to download
        taskDict = dictonary with url as key and DownloadStatus as value
        parallelProcesses = number of processes downloading in parallel
        """

        self.taskQueue = taskQueue
        self.taskDict = taskDict
        self.parallelProcesses = parallelProcesses
        self.processes = []

        self._downloadFunc = trailerDownload


    def start(self):
        for i in range(self.parallelProcesses):
            p = Process(target=trailerDownload,
                        args=(self.taskQueue,
                              self.taskDict))
            p.start()
            self.processes.append(p)

    def stop(self):
        for p in self.processes:
            p.terminate()




def trailerDownload(taskQueue, taskDict):
    # we need to have consistent wget output
    locale.setlocale(locale.LC_ALL, "C")
    signal.signal(signal.SIGTERM, term_handler)
    try:
        while True:
            trailerURL, targetDir = taskQueue.get()
            command = ['wget','-cN',
                       '-U',
                       'QuickTime/7.6.2 (qtver=7.6.2;os=Windows NT 5.1Service Pack 3)',
                       trailerURL,
                       '-P',
                       targetDir,
                       '--progress=dot:mega']
            downloadFunc(trailerURL, command, taskDict)
    except ClosingException as e:
        pass

wgetPids=[]
def downloadFunc(trailerURL, command, taskDict):
    print("Executing: %s" % " ".join(command))
    p = subprocess.Popen(command,
                         stdout=subprocess.PIPE,
                         stderr=subprocess.PIPE)
    taskDict[trailerURL] = DownloadStatus(trailerURL,
                                          DownloadStatus.IN_PROGRESS)
    wgetPids.append(p.pid)
    totalsize = 0
    while True:
        line = p.stderr.readline().decode()
        if len(line) == 0:
            break
        if line.find('Length:') != -1:
            totalsize = int(line.split(' ')[1])
            break

    # now we start counting dots :-)
    downloaded = 0
    while True:
        x = p.stderr.read(1).decode()

        if len(x) == 0:
            break
        if x == '.' or x ==',':
            downloaded = downloaded + 64 * 1024
        perc = int(downloaded * 100 / totalsize)
        if perc % 5 == 0:
            try:
                taskDict[trailerURL] = DownloadStatus(trailerURL,
                           DownloadStatus.IN_PROGRESS,
                           perc)
            except IOError as e:
                print("Ignoring interrupted assignement exception")
                if e.errno is not errno.EINTR:
                    raise

    p.wait()
    if p.returncode is not 0:
        taskDict[trailerURL] = DownloadStatus(trailerURL,
                           DownloadStatus.ERROR)
    else:
        taskDict[trailerURL] = DownloadStatus(trailerURL,
                           DownloadStatus.DONE)
    wgetPids.remove(p.pid)


def term_handler(signum, frame):
    for p in wgetPids:
        print('Stopping wget process ', p)
        os.kill(p, signal.SIGTERM)
    raise ClosingException("Finishing up")
